#### Building instructions.
#
### Overview of rebuild options:
#
# --without userland		: Build without the userland-package (default: with it)
# --without modules		: Build without the kernel-module-package (default: with it)
# --define 'ksrc srcdir' 	: Build with kernel header files found in <srcdir> 
# --define 'kernel kernelver' 	: Build for kernel <kernelver> instead of the current. Might in some cases 
#                                  needed in addition to ksrc or to build for a different fedora-kernel.  
#
### Examples:
#
## To rebuild whole package for the running kernel:
#
# rpmbuild -ba THIS.SPEC --target "$(uname -m)"
# 
## To rebuild only userland-package: 
#
# rpmbuild -ba THIS.SPEC --without modules
#
## To rebuild only kernel modules against currently running fedora kernel 
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" 
#
## To rebuild only kernel modules against a kernel where /lib/modules/$(uname -r)/build points
##  to the build-sources (e.g. self compiled, fedora-kernel without kernel-devel package)
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" --define "ksrc /lib/modules/$(uname -r)/build" 
#
#### End of Building instructions.


%{?ksrc: 	%{!?kernel:    %{expand: %%define kernel %(cd "%{ksrc}" &> /dev/null && echo "$(cat Makefile 2>/dev/null && echo $'\n'kernelhelper-rel:$'\n'$'\t'@echo \$\(KERNELRELEASE\)$'\n')" 2>/dev/null | make -f - kernelhelper-rel 2>/dev/null || echo "custom" ) }}}
%{!?kernel:             %{expand: %%define kernel %(uname -r)}}
%define modpath   	kernel/drivers/char/drm
%define atilibdir 	%{_libdir}/ati-fglrx
%define atilibdir32bit 	%{_prefix}/lib/ati-fglrx
%define	x11dir		%{_prefix}/X11R6
%define	x11libdir	%{x11dir}/%{_lib}
%define	x11libdir32bit	%{x11dir}/lib
%define	x11bindir	%{x11dir}/bin

Name:           ati-fglrx
Version:        8.18.6.1
Release:        0.SL.1
Epoch:          0
Summary:        ATI proprietary driver for ATI Radeon graphic cards

Group:          User Interface/X Hardware Support
License:        Distributable
URL:            http://www.ati.com/support/drivers/linux/radeon-linux.html

# No full URL possible (AFAICS), need to download it from:
# https://support.ati.com/ics/support/default.asp?deptID=894&task=knowledge&folderID=300
Source0:        fglrx_6_8_0-8.18.6-1.i386.rpm
Source1:        fglrx64_6_8_0-8.18.6-1.x86_64.rpm

Source3:        %{name}-README.fglrx.Fedora
Source4:	%{name}-fireglcontrol.desktop
Source10:       %{name}-config-display
Source11:       %{name}.init	
Source12:	%{name}.profile.d

Patch0:		%{name}-panel_sources.diff
Patch1:		%{name}-makefile.diff
Patch2:		%{name}-makesh.diff
Patch10:	%{name}-via_int_agpgart.patch

ExclusiveArch:  x86_64 %{ix86}
Requires(post): /sbin/ldconfig
Requires(postun): /sbin/ldconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

Conflicts:	fglrx
Conflicts:	nvidia-glx
Conflicts:	nvidia-glx-legacy
%if 0%{!?_without_userland:1}
BuildRequires:  qt-devel, desktop-file-utils
%endif

%description
This Package contains the X11 driver, utilities and libraries needed for the
ATI proprietary driver for ATI Radeon graphic cards.


%package devel
Summary:        ATI proprietary driver for ATI Radeon graphic cards, devel part
Group:		Development/Libraries

Requires:	ati-fglrx = %{epoch}:%{version}-%{release}
Requires:	%{_prefix}/X11R6/include/X11/extensions, %{_includedir}/GL

%description devel
This package provides header files and examples required for development
for the ATI proprietary driver for ATI Radeon graphic cards.


%package -n kernel-module-fglrx-%{kernel}
Summary:         ATI proprietary driver for ATI Radeon graphic cards, kernel part
Group:		 System Environment/Kernel

Provides:	 kernel-module-fglrx = %{epoch}:%{version}-%{release}
Requires:	 ati-fglrx >= %{epoch}:%{version}-0.SL.1
Requires(post):  modutils
Requires(postun):modutils
%if 0%{!?ksrc:1}
Requires:	 /boot/vmlinuz-%{kernel}
%endif
%if 0%{!?_without_modules:1}
%if 0%{!?ksrc:1}
BuildRequires:  kernel-devel = %{kernel}
%endif
%endif

%description  -n kernel-module-fglrx-%{kernel}
This Package contains the kernel modules required for 3D acceleration with
the ATI proprietary driver for ATI Radeon graphic cards.  This package is
built for kernel %{kernel} (%{_target_cpu}).


%prep
if [[ "%{kernel}" = "custom" ]]
then
	(
	set +ex
	echo $'\n'$'\n'"Could not determine your kernel version. You should pass the correct one with"
	echo "the rpmbuild parameter '--define \"kernel <output of uname -r of target kernel>\"'"
	echo "But probably there is something wrong with the ksrc you provided. Therefore the"
	echo "build might fail, too."$'\n'$'\n'
	)
	sleep 10
fi
%setup -c -T
mkdir fglrx
cd ./fglrx
%ifarch %{ix86}
rpm2cpio %{SOURCE0} | cpio --quiet --no-absolute-filenames -idmv 
%else
rpm2cpio %{SOURCE1} | cpio --quiet --no-absolute-filenames -idmv 
%endif
cd ..

%if 0%{!?_without_modules:1}
find fglrx/lib/modules/fglrx/build_mod/ fglrx/usr/share/doc  -type d -print0 | xargs -0 chmod 0755
find fglrx/lib/modules/fglrx/build_mod/ -type f -print0 | xargs -0 chmod 0644
find fglrx/usr/share/doc -type f -print0 | xargs -0 chmod 0444
cd fglrx/lib/modules/fglrx/build_mod/
%patch1 -b .patch1
%patch2 -b .patch2
%patch10 -p1 -b .patch10
sed -i 's|include "asm/ioctl32.h"|include "linux/ioctl32.h"|' firegl_public.c
cd -
%endif  #!?_without_modules:1

%if 0%{!?_without_userland:1}
# problem in 8.18.6.1:
rm fglrx/%{x11libdir}/modules/drivers/fglrx_drv.o.orig
# we compile our own:
rm fglrx/%{x11bindir}/fireglcontrolpanel
mkdir -p fglrx_panel_sources
cd fglrx_panel_sources
tar -xzf ../fglrx/usr/src/ATI/fglrx_panel_sources.tgz
%patch0 -p0 -b .patch0
# we want to strip the binary
sed -i 's|STRIP = strip|STRIP = @echo strip is disabled for:|' Makefile
# correct name
sed -i 's|BASENAME =  fireglcontrol|BASENAME =  fireglcontrolpanel|' Makefile
cd ..
%endif  #!?_without_userland:1


%build
%if 0%{!?_without_modules:1}
cd fglrx/lib/modules/fglrx/build_mod/
export AS_USER=y
export KERNEL_PATH="%{?ksrc:%{ksrc}}%{!?ksrc:%{_usrsrc}/kernels/%{kernel}-%{_target_cpu}}"
export FEDORA_UNAME_R="%{kernel}"
export FEDORA_UNAME_M="%{_target_cpu}"
export CC="gcc"
bash make.sh verbose
cd ../../../../../
%endif 	#!?_without_modules:1

%if 0%{!?_without_userland:1}
[ -n "$QTDIR" ] || . %{_sysconfdir}/profile.d/qt.sh
cd fglrx_panel_sources
make %{?_smp_mflags}
cd ..
%endif  #!?_without_userland:1


%install
rm -rf $RPM_BUILD_ROOT

%if 0%{!?_without_modules:1}
# mode 755 here to allow rpm to strip the module, fixed later in %%files
# since 8.16.20 stripping does not work anymore -- install 644 for now
install -D -p -m 0644 fglrx/lib/modules/fglrx/build_mod/2.6.x/fglrx.ko $RPM_BUILD_ROOT/lib/modules/%{kernel}/%{modpath}/fglrx.ko
%endif  #!?_without_modules:1


%if 0%{!?_without_userland:1}
for file in $(cd fglrx &> /dev/null; find usr/ -type f | grep -v -e 'fireglcontrol.kdelnk$' -e 'fireglcontrol.desktop$' -e 'ati.xpm$' -e 'fglrx_panel_sources.tgz' -e 'fglrx_sample_source.tgz')
do
  if [[ "/${file}" = "%{x11libdir}/libGL.so.1.2" ]]
  then
    install -D -p -m 0755 fglrx/%{x11libdir}/libGL.so.1.2 $RPM_BUILD_ROOT%{atilibdir}/libGL.so.1.2
    ln -s libGL.so.1.2 $RPM_BUILD_ROOT%{atilibdir}/libGL.so.1
  elif [[ "/${file}" = "%{x11libdir32bit}/libGL.so.1.2" ]]
  then
    install -D -p -m 0755 fglrx/%{x11libdir32bit}/libGL.so.1.2 $RPM_BUILD_ROOT%{atilibdir32bit}/libGL.so.1.2
    ln -s libGL.so.1.2 $RPM_BUILD_ROOT%{atilibdir32bit}/libGL.so.1
  elif grep -e '/bin/' -e '\.so$' -e '\.so\.[0-9]' <<<"${file}"
  then
    install -D -p -m 0755 fglrx/${file} $RPM_BUILD_ROOT/${file}
  else
    install -D -p -m 0644 fglrx/${file} $RPM_BUILD_ROOT/${file}
  fi
done
mv $RPM_BUILD_ROOT/usr/share/doc/fglrx $RPM_BUILD_ROOT/%{_docdir}/%{name}-%{version}
ln -s libfglrx_gamma.so.1.0 $RPM_BUILD_ROOT/%{x11libdir}/libfglrx_gamma.so.1
install -D -p -m 0644 fglrx_panel_sources/ati.xpm $RPM_BUILD_ROOT/%{_datadir}/pixmaps/ati.xpm
install -D -p -m 0755 fglrx_panel_sources/fireglcontrolpanel $RPM_BUILD_ROOT/%{x11bindir}/fireglcontrolpanel
install -D -p -m 0644 %{SOURCE3} fglrx/usr/share/doc/fglrx/%(basename %{SOURCE3})
install -D -p -m 0755 %{SOURCE10} $RPM_BUILD_ROOT%{_sbindir}/%(basename %{SOURCE10})
install -D -p -m 0755 %{SOURCE11} $RPM_BUILD_ROOT%{_initrddir}/ati-fglrx
install -D -p -m 0755 %{SOURCE12} $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/ati-fglrx.sh

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/
echo "disabled" > $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/ati-fglrx-config-display

mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
desktop-file-install --vendor livna \
    --dir $RPM_BUILD_ROOT%{_datadir}/applications \
    --add-category X-Livna \
    --add-category Application \
    --add-category System \
    %{SOURCE4}

%endif  #!?_without_userland:1


%clean
rm -rf $RPM_BUILD_ROOT


%post
if [ "${1}" -eq 1 ]; then
  # We want to choose and load fglrx libGL before X11/system libGL
  if ! grep -v -m 1 -e '/%{x11libdir}/' /etc/ld.so.conf | grep -e '^include ld.so.conf.d/\*.conf' &>/dev/null ; then
    # Add ld.so.conf include entry in the first line
    /bin/grep -v -e '^include ld.so.conf.d/\*.conf' %{_sysconfdir}/ld.so.conf > %{_sysconfdir}/ld.so.conf~
    /bin/echo 'include ld.so.conf.d/*.conf' > %{_sysconfdir}/ld.so.conf
    /bin/cat %{_sysconfdir}/ld.so.conf~ >> %{_sysconfdir}/ld.so.conf
  fi
  # Enable ati-fglrx driver
  test -f %{_sbindir}/ati-fglrx-config-display && %{_sbindir}/ati-fglrx-config-display enable &>/dev/null ||:
  # Add init script and start it
  /sbin/chkconfig --add ati-fglrx
  /etc/init.d/ati-fglrx start &>/dev/null
fi ||:
if [ "${1}" -gt 1 ]; then
  /sbin/ldconfig
fi

%preun 
if [ "${1}" -eq 0 ]; then
  /etc/init.d/ati-fglrx stop &>/dev/null
  # Disable driver, but only on final removal
  /sbin/chkconfig --del ati-fglrx
  test -f %{_sbindir}/ati-fglrx-config-display && %{_sbindir}/ati-fglrx-config-display disable &>/dev/null ||:
fi ||:

%postun -p /sbin/ldconfig

%post -n kernel-module-fglrx-%{kernel}
%if 0%{!?ksrc:1}
if [ -r /boot/System.map-%{kernel} ] ; then
  /sbin/depmod -e -F /boot/System.map-%{kernel} %{kernel} > /dev/null || :
fi
%else
if [ "$(uname -r)" = "%{kernel}" ] ; then
  /sbin/depmod -a >/dev/null || :
fi
%endif


%postun -n kernel-module-fglrx-%{kernel}
%if 0%{!?ksrc:1}
if [ -r /boot/System.map-%{kernel} ] ; then
  /sbin/depmod -e -F /boot/System.map-%{kernel} %{kernel} > /dev/null || :
fi
%else
if [ "$(uname -r)" = "%{kernel}" ] ; then
  /sbin/depmod -a >/dev/null || :
fi
%endif


%if 0%{!?_without_modules:1}
%files -n kernel-module-fglrx-%{kernel}
%defattr(744,root,root,-)
/lib/modules/%{kernel}/%{modpath}/fglrx.ko
%endif  #!?_without_modules:1

%if 0%{!?_without_userland:1}
%files
%defattr(-,root,root,-)
%doc %{_docdir}/%{name}-%{version}
%{_datadir}/pixmaps/ati.xpm
%{_sysconfdir}/profile.d/ati-fglrx.sh
%{x11bindir}/aticonfig
%{x11bindir}/fgl_glxgears
%{x11bindir}/fglrxconfig
%{x11bindir}/fglrxinfo
%{x11bindir}/fglrx_pplay
%{x11bindir}/fglrx_xgamma
%{x11bindir}/fireglcontrolpanel
%{x11libdir}/libaticonfig.a
%{x11libdir}/libfglrx_pp.*
%{x11libdir}/modules/dri/*.so
%{x11libdir}/modules/drivers/fglrx_drv.o
%{x11libdir}/modules/linux/libfglrxdrm.a
%{x11libdir}/libfglrx_gamma.*
%{_initrddir}/ati-fglrx
%{_sbindir}/ati-fglrx-config-display
%{_datadir}/applications/livna-ati-fglrx-fireglcontrol.desktop
%{atilibdir}/
%ifarch x86_64
%{atilibdir32bit}/
%{x11libdir32bit}/modules/dri/*.so
%endif
%ghost %{_sysconfdir}/sysconfig/ati-fglrx-config-display

%files devel
%defattr(-,root,root,-)
%doc fglrx/usr/src/ATI/fglrx_sample_source.tgz
%{_includedir}/GL/glxATI.h
%{_includedir}/GL/glATI.h
%{x11dir}/include/X11/extensions/fglrx_gamma.h
%endif  #!?_without_userland:1


%changelog
* Thu Oct 13 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.18.6.1-0.lvn.1
- Update to 8.18.6-1
- Conflict with nvidia-glx{,-legacy) (#627)
- Fix moduleline.split in ati-fglrx-config-display (#582)
- Unload drm in ati-fglrx-config-display, too
- Only ship self compiled fireglcontrolpanel

* Fri Aug 19 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.16.20.1-0.lvn.1
- Update to 8.16.20-1
- Update patch1, fireglcontrol.desktop
- Don't strip kernel-module for now

* Tue Jun 07 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.14.13.1-0.lvn.5
- Update fglrx-2.6.12-inter_module_get.patch (thx to Mike Duigou)

* Tue Jun 07 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.14.13.1-0.lvn.4
- Add patches from http://ati.cchtml.com/show_bug.cgi?id=136 and some tricks 
  to built with 2.6.12 -- fixes building for FC4

* Tue Jun 07 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.14.13.1-0.lvn.3
- Missed one thing during reword of kernel-module-build-stuff
- Both x86_64 and x86 in the same package now

* Sun Jun 05 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.14.13.1-0.lvn.2
- Fix thinko

* Sun Jun 05 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.14.13.1-0.lvn.1
- Rework kernel-module-build-stuff for FC3 kmd and FC4 and new livna scheme
- Simplify the install; Lowers risk to miss files and is easier to maintain
- Remove dep on fedora-rpmdevtools
- Use modules and userland rpmbuild parameter to not build kernel- or driver-package  

* Wed May 04 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.12.10.1-0.lvn.2
- Add fix for kernel 2.6.11

* Fri Apr 08 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.12.10.1-0.lvn.1
- Update to 8.12.10-1
- mod 0755 dri.so to let rpm detect require libstdc++.so.5

* Thu Mar 06 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.10.19.1-0.lvn.2
- Add patch for via agpgart (#355)

* Thu Feb 17 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.10.19.1-0.lvn.1
- Update to 8.10.19-1
- Remove patch for 2.6.10 kernel
- require libstdc++.so.5

* Wed Jan 19 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.8.25.1-0.lvn.4
- fix x86-64 in spec-file and in ati-fglrx-config-display
- Fix by Ville Skyttä: ldconfig on upgrades  

* Wed Jan 19 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.8.25.1-0.lvn.3
- Package library links

* Wed Jan 19 2005 Dams <anvil[AT]livna.org> - 0:8.8.25.1-0.lvn.2
- Urlized ati rpm source

* Sat Jan 15 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:8.8.25.1-0.lvn.1
- Update to 8.8.25
- Remove workaround from last version
- Remove special drm includes
- Prepare package for 64-bit version; But untested ATM
- Update patches

* Tue Jan 11 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.14.6-0.lvn.3
- add patch10 -- allows building on 2.6.10; Found:
  http://www.rage3d.com/board/showthread.php?t=33798874&highlight=2.6.10
- update drm-includes
- temporary for kernel-module:  Requires: ati-fglrx >= %{epoch}:%{version}-0.lvn.2
  so we don't have to rebuild the driver package

* Sun Nov 21 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.14.6-0.lvn.2
- Use kernelp and driverp rpmbuild parameter to not build kernel- or 
  driver-package  
- Trim doc in header

* Fri Nov 04 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.14.6-0.lvn.1
- Update to 3.14.6

* Fri Nov 04 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.14.1-0.lvn.7
- Build per default without kmoddev
- Rename --without tools to --without dirverp
- Update dri-headers to 2.6.9 version 
- update building documentation in header

* Fri Oct 22 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.14.1-0.lvn.6
- Some small cleanups to various parts of the package as suggested by Dams

* Fri Oct 22 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.14.1-0.lvn.5
- Enhance makefile patch so building with different uname should work correctly
- Build verbose

* Thu Oct 21 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.14.1-0.lvn.4
- Update fedora-unrpm usage to work with newer version
- Update one para in README and ati-fglrx-config-display output

* Fri Oct 15 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.14.1-0.lvn.3
- Change the enabling/disabling methode again -- driver is changed now 
  directly. DRI is enabled when fglrx is enabled, but try to unload/warn if
  radeon kernel-module is loaded. DRI will be disabled and reenabled on the 
  when next restart when disableing fglrx driver. 
- Update README.fglrx.Fedora

* Mon Oct 11 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.14.1-0.lvn.2
- Let new version of ati-flrx-config-display change default depth to 24
- Updated Spec-File bits: fedora-kmodhelper usage and building description

* Thu Sep 30 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.14.1-0.lvn.1
- Update to 3.14.1
- In expectation of missing kernel-sourcecode package in FC3 remove the BR
  on it and include the neccessary header-files in the package. Will
  integrate more packages if there are API changes. But for now I
  think this is the easiest methode.
- Let ati-flrx-config-display handle /etc/ld.so.conf.d/ati-fglrx.conf
- Update ati-flrx-config-display; it adds a VideoOverlay Option now 
  so xv works out of the box
- Don't (de)activate driver if DRI-Kernel-Modules are loaded; Let the
  init script to that during restart
- Update README.fglrx.Fedora 

* Wed Sep 29 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:3.12.0-0.lvn.2
- Allow rpm to strip the kernel module.
- Fix shared library permissions.
- Split Requires(post,postun) to two to work around a bug in rpm.
- Fix -devel dependencies and kernel module package provisions.
- Improve summary and description, remove misleading comments.

* Sat Sep 11 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.12.0-0.lvn.1
- Update to 3.12.0
- Fix some fedora-kmodhelper/kernel-module related bits in spec
- Clean up install part a bit more 

* Sun Sep 05 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.11.1-0.lvn.6
- Add stupid ati-fglrx.profile.d workaround for systems that had the
  original fglrx drivers installed before
- Conflict with fglrx -- the package should be removed so it can clean up
  the mess it did itself. 
- Clean up desktop file

* Tue Aug 24 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.11.1-0.lvn.5
- Add ifdefs so building tools and kernel-module can be separated
- BuildRequire kernel-sourcecode kverrel, not kernel

* Wed Aug 17 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.11.1-0.lvn.4
- Fixed double release in Requires of devel-package
- Building against custom kernels now should work using rhkernel-macro
- Updated fedora-kmodhelper to 0.9.10
- Add 'include ld.so.conf.d/*.conf' before /usr/lib/X11 in /etc/ld.so.conf if
  it does not exists

* Wed Aug 10 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.11.1-0.lvn.3
- small fixes for dump issues

* Thu Aug 09 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.11.1-0.lvn.2
- BuildRequire fedora-rpmdevtools
- Use KERNEL_PATH correctly, needs updated patch1

* Sat Aug 07 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.11.1-0.lvn.1
- Update to 3.11.1
- Minor fixes

* Fri Aug  6 2004 Dams <anvil[AT]livna.org> 0:3.9.0-0.lvn.4
- .a files are 0644 moded. tgz files too.
- Added missing BuildReq: desktop-file-utils, qt-devel, fedora-rpmdevtools

* Mon Jul 19 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.9.0-0.lvn.3
- Update Patches to a working solution
- Modify start-script-- fglrx can also work without kernel-module (no DRI then)

* Sun Jul 18 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.9.0-0.lvn.2
- intergrate Readme, init-script and ati-fglrx-config-display (stolen from
  nvidia package) 

* Sat Jul 17 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:3.9.0-0.lvn.1
- Initial RPM release.
